AnalyticsPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • AnalyticsPlatform
Implementers

Constructors

AnalyticsPlatform()
Constructs a AnalyticsPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
linkStream → Stream<Map<String, dynamic>>
A broadcast stream for receiving incoming link change events.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getContext({bool collectDeviceId = false}) → Future<NativeContext>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ AnalyticsPlatform
The default instance of AnalyticsPlatform to use.
getter/setter pair