ClientMethods mixin

Mixin applications

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

alias(String newUserId) → Future
flush() → Future
group(String groupId, {GroupTraits? groupTraits}) → Future
identify({String? userId, UserTraits? userTraits}) → Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset({bool? resetAnonymousId}) → Future
screen(String name, {Map<String, dynamic>? properties}) → Future
toString() → String
A string representation of this object.
inherited
track(String event, {Map<String, dynamic>? properties}) → Future

Operators

operator ==(Object other) → bool
The equality operator.
inherited