TimerFlushPolicy class

Inheritance

Constructors

TimerFlushPolicy(int _interval)
@param interval interval to flush in milliseconds

Properties

debugState → bool
A development-only way to access state outside of StateNotifier.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
If a listener has been added using addListener and hasn't been removed yet.
no setterinherited
mounted → bool
Whether dispose was called or not.
no setterinherited
onError ↔ ErrorListener?
A callback for error reporting if one of the listeners added with addListener throws.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldFlush ↔ bool
getter/setter pairinherited
state ↔ bool
The current "state" of this StateNotifier.
getter/setter pairinherited
stream → Stream<bool>
A broadcast stream representation of a StateNotifier.
no setterinherited

Methods

addListener(Listener<bool> listener, {bool fireImmediately = true}) → RemoveListener
Subscribes to this object.
inherited
dispose() → void
Frees all the resources associated to this object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onEvent(RawEvent event) → void
Executed every time an event is tracked by the client @param event triggered event
override
reset() → void
Resets the values of this policy.
override
start() → void
Start gets executed when the FlushPolicy is added to the client.
override
toString() → String
A string representation of this object.
inherited
updateShouldNotify(bool old, bool current) → bool
Whether to notify listeners or not when state changes
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited