NativeContext class

Constructors

NativeContext({NativeContextApp? app, NativeContextDevice? device, NativeContextLibrary? library, String? locale, NativeContextNetwork? network, NativeContextOS? os, NativeContextScreen? screen, String? timezone, String? userAgent})

Properties

app ↔ NativeContextApp?
getter/setter pair
device ↔ NativeContextDevice?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
library ↔ NativeContextLibrary?
getter/setter pair
locale ↔ String?
getter/setter pair
network ↔ NativeContextNetwork?
getter/setter pair
os ↔ NativeContextOS?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screen ↔ NativeContextScreen?
getter/setter pair
timezone ↔ String?
getter/setter pair
userAgent ↔ String?
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → NativeContext