NativeContextDevice class

Constructors

NativeContextDevice({String? id, String? manufacturer, String? model, String? name, String? type, bool? adTrackingEnabled, String? advertisingId, String? trackingStatus, String? token})

Properties

adTrackingEnabled ↔ bool?
getter/setter pair
advertisingId ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
manufacturer ↔ String?
getter/setter pair
model ↔ String?
getter/setter pair
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token ↔ String?
getter/setter pair
trackingStatus ↔ String?
getter/setter pair
type ↔ String?
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → NativeContextDevice