EventPlugin class abstract

Inheritance
Mixed-in types
Implementers

Constructors

EventPlugin(PluginType type)

Properties

analytics → Journify?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
pAnalytics ↔ Journify?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → PluginType
finalinherited

Methods

alias(AliasEvent event) → Future<RawEvent?>
clear() → void
inherited
configure(Journify journify) → void
inherited
execute(RawEvent event) → Future<RawEvent?>
override
flush() → Future
override
group(GroupEvent event) → Future<RawEvent?>
identify(IdentifyEvent event) → Future<RawEvent?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
override
screen(ScreenEvent event) → Future<RawEvent?>
shutdown() → void
inherited
toString() → String
A string representation of this object.
inherited
track(TrackEvent event) → Future<RawEvent?>
update(Map<String, dynamic> settings, ContextUpdateType type) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited