Configuration class

Constructors

Configuration(String writeKey, {String? apiHost, bool autoAddJournifyDestination = true, bool collectDeviceId = false, bool enableHashing = false, String cdnHost = HTTPClient.defaultCDNHost, Map<String, dynamic>? defaultIntegrationSettings, ErrorHandler? errorHandler, List<FlushPolicy>? flushPolicies, StreamSubscription<AppStatus> appStateStream()?, RequestFactory? requestFactory, bool trackApplicationLifecycleEvents = false, bool trackDeeplinks = false, bool debug = false, int? maxBatchSize, bool? storageJson = true, String? token})

Properties

apiHost → String?
final
appStateStream → StreamSubscription<AppStatus> Function()?
final
autoAddJournifyDestination → bool
final
cdnHost → String
final
collectDeviceId → bool
final
debug → bool
final
defaultIntegrationSettings → Map<String, dynamic>?
final
enableHashing → bool
final
errorHandler → ErrorHandler?
final
flushPolicies → List<FlushPolicy>?
final
hashCode → int
The hash code for this object.
no setterinherited
maxBatchSize → int?
final
requestFactory → RequestFactory?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageJson → bool?
final
token → String?
final
trackApplicationLifecycleEvents → bool
final
final
writeKey → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited