HTTPClient class

Constructors

HTTPClient(Journify analytics)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
settingsFor(String writeKey) → Future<JournifyAPISettings?>
startBatchUpload(String writeKey, List<RawEvent> batch, {String? host}) → Future<bool>
Starts an upload of events. Responds appropriately if successful or not. If not, lets the respondant know if the task should be retried or not based on the response.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultAPIHost → const String
defaultCDNHost → const String